#
# spec file for package telegram-purple
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           telegram-purple
Version:        1.4.2
Release:        lp152.1.3
Summary:        Plugin for Pidgin for supporting Telegram messager
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Networking/Instant Messenger
URL:            https://github.com/majn/telegram-purple
Source:         https://github.com/majn/telegram-purple/releases/download/v%{version}/%{name}_%{version}.orig.tar.gz
# PATCH-FIX-UPSTREAM telegram-purple-tl-parser-format-overflow.patch sor.alexei@meowr.ru -- Fix format overflow in tl-parser.
Patch0:         telegram-purple-tl-parser-format-overflow.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  intltool
BuildRequires:  libgcrypt-devel >= 1.6
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(purple)
BuildRequires:  pkgconfig(zlib)

%description
A Pidgin plugin that adds support for the Telegram messenger.

%package -n libpurple-plugin-telegram
Summary:        Plugin for libpurple for supporting Telegram messager
Group:          Productivity/Networking/Instant Messenger
Recommends:     libpurple-plugin-telegram-lang
Enhances:       libpurple
# telegram-purple was last used in openSUSE Leap 14.2.
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libpurple-plugin-telegram
A libpurple plugin that adds support for the Telegram messenger.

%lang_package -n libpurple-plugin-telegram

%package -n pidgin-plugin-telegram
Summary:        Plugin for Pidgin for supporting Telegram messager
Group:          Productivity/Networking/Instant Messenger
Requires:       libpurple-plugin-telegram = %{version}
%requires_ge    pidgin
Supplements:    packageand(libpurple-plugin-telegram:pidgin)
BuildArch:      noarch

%description -n pidgin-plugin-telegram
A Pidgin plugin that adds support for the Telegram messenger.

This package provides the icon set for Pidgin.

%prep
%setup -q -n %{name}
%patch0 -p1

%build
autoreconf -fi
%configure
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang telegram-purple

%files -n libpurple-plugin-telegram
%license COPYING
%doc AUTHORS CHANGELOG.md README.md
%config %{_sysconfdir}/telegram-purple/
%{_libdir}/purple-2/telegram-purple.so
%dir %{_datadir}/appdata/
%{_datadir}/appdata/telegram-purple.metainfo.xml

%files -n libpurple-plugin-telegram-lang -f telegram-purple.lang

%files -n pidgin-plugin-telegram
%dir %{_datadir}/pixmaps/pidgin/
%dir %{_datadir}/pixmaps/pidgin/protocols/
%dir %{_datadir}/pixmaps/pidgin/protocols/*/
%{_datadir}/pixmaps/pidgin/protocols/*/telegram.*

%changelog
* Wed Feb  5 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Upgrade to 1.4.2
  - Support ancient glib (gh#501)
  - Update translations
  - Fix: Handle forwarded messages and captioned images better
  - Fix: Handle replies better
  - Fix: Images in own messages
  - Fix: Remove *some* of the duplicate messages seen
* Mon Mar 25 2019 Matej Cepl <mcepl@suse.com>
- Upgrade to 1.4.1:
  - Had to skip 1.4.0 as someone distributed an intermediate
    version as "1.4.0"
  - Import awesomeness from kenorb's mega-merge:
  - Support for pinned and other action types
  - Stability improvements in general
  - Better build support:
  - No -Werror
    + Drop telegram-purple-1.3.1-disable-werror.patch
  - Compatibility with LibreSSL
  - Compatibility with C++
  - Simplify: Only one level of submodules
  - Add support for replies/forwarded messages
  - Add support for IPv6-only
  - Add windows cross-compilation script
* Sat Aug 11 2018 jengelh@inai.de
- Update grammar in summaries.
* Sat Aug  4 2018 sor.alexei@meowr.ru
- Add telegram-purple-1.3.1-disable-werror.patch: Disable -Werror.
* Mon Jun 12 2017 sor.alexei@meowr.ru
- Add telegram-purple-tl-parser-format-overflow.patch: Fix format
  overflow in tl-parser.
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 1.3.1:
  * Stability improvements.
  * Support auto-loading for documents.
  * Add support for "typing" in group chats (using
    group-typing-notifications plugin).
  * Add support for the /kick command in group chats.
* Fri Dec 16 2016 sor.alexei@meowr.ru
- Update to version 1.3.0:
  * Channel/supergroup support.
  * Support sending code tags in markdown 'backtick' format.
  * Reduce amount of file-transfer popups in Pidgin, auto-load
    media in the background.
  * Fix multiple crashes in libtgl.
- Rename the telegram-purple package to libpurple-plugin-telegram.
- Separate Pidgin icons to pidgin-plugin-telegram.
- Separate locales to libpurple-plugin-telegram-lang.
- Don't own Pidgin pixmap directories.
- Don't require appstream-glib and openssl.
* Sun Jul  3 2016 mailaender@opensuse.org
- update to version 1.2.6, see included CHANGELOG.md
* Sun Mar  6 2016 mailaender@opensuse.org
- update to version 1.2.5, see included CHANGELOG.md
* Tue Sep 22 2015 dmitry_r@opensuse.org
- Update to version 1.2.1, see included CHANGELOG.md
* Fri Nov  7 2014 dmitry_r@opensuse.org
- Initial package, version 0.3.3
